==> gromacs_2018.3.orig.tar.gz: gromacs-2018.3/src/gromacs/utility/ikeyvaluetreeerror.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2016, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares an error handling interface for key-value tree operations.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_KEYVALUETREEERROR_H
#define GMX_UTILITY_KEYVALUETREEERROR_H

namespace gmx
{

class KeyValueTreePath;
class UserInputError;

class IKeyValueTreeErrorHandler
{
    public:
        virtual bool onError(UserInputError *ex, const KeyValueTreePath &context) = 0;

    protected:
        ~IKeyValueTreeErrorHandler();
};

//! \cond libapi
/*! \brief
 * Returns a default IKeyValueTreeErrorHandler that throws on first exception.
 *
 * \ingroup module_utility
 */
IKeyValueTreeErrorHandler *defaultKeyValueTreeErrorHandler();
//! \endcond

} // namespace gmx

#endif

==> gromacs_2019.3.orig.tar.gz: gromacs-2019.3/src/gromacs/utility/ikeyvaluetreeerror.h <==
/*
 * This file is part of the GROMACS molecular simulation package.
 *
 * Copyright (c) 2016,2018, by the GROMACS development team, led by
 * Mark Abraham, David van der Spoel, Berk Hess, and Erik Lindahl,
 * and including many others, as listed in the AUTHORS file in the
 * top-level source directory and at http://www.gromacs.org.
 *
 * GROMACS is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; either version 2.1
 * of the License, or (at your option) any later version.
 *
 * GROMACS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with GROMACS; if not, see
 * http://www.gnu.org/licenses, or write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA.
 *
 * If you want to redistribute modifications to GROMACS, please
 * consider that scientific software is very special. Version
 * control is crucial - bugs must be traceable. We will be happy to
 * consider code for inclusion in the official distribution, but
 * derived work must not be called official GROMACS. Details are found
 * in the README & COPYING files - if they are missing, get the
 * official version at http://www.gromacs.org.
 *
 * To help us fund GROMACS development, we humbly ask that you cite
 * the research papers on the package. Check out http://www.gromacs.org.
 */
/*! \libinternal \file
 * \brief
 * Declares an error handling interface for key-value tree operations.
 *
 * \author Teemu Murtola <teemu.murtola@gmail.com>
 * \inlibraryapi
 * \ingroup module_utility
 */
#ifndef GMX_UTILITY_KEYVALUETREEERROR_H
#define GMX_UTILITY_KEYVALUETREEERROR_H

namespace gmx
{

class KeyValueTreePath;
class UserInputError;

class IKeyValueTreeErrorHandler
{
    public:
        virtual bool onError(UserInputError *ex, const KeyValueTreePath &context) = 0;

    protected:
        virtual ~IKeyValueTreeErrorHandler();
};

//! \cond libapi
/*! \brief
 * Returns a default IKeyValueTreeErrorHandler that throws on first exception.
 *
 * \ingroup module_utility
 */
IKeyValueTreeErrorHandler *defaultKeyValueTreeErrorHandler();
//! \endcond

} // namespace gmx

#endif
